## ----global_options, include=FALSE------------------------------------------------------------------------------------
library(knitr)
knitr::opts_chunk$set(dpi = 100, 
                      echo= TRUE, 
                      warning=FALSE, 
                      message=FALSE, 
                      fig.show=TRUE, 
                      fig.keep = 'all',
                      out.width = "70%")


## ----echo = FALSE-----------------------------------------------------------------------------------------------------
library(mixOmics) # import the mixOmics library

load('Data/rna.data.RData') # load the gastrulation data
load('Data/met.data.RData')
load('Data/acc.data.RData')

X1 <- rna.data$rna # select the five dataframes to explore
X2 <- met.data$met_genebody
X3 <- acc.data$acc_genebody
X4 <- met.data$met_promoter
X5 <- acc.data$acc_promoter

# compile these into a single X object
X <- list(rna = X1, met.gene = X2, acc.gene = X3,
          met.pro = X4, acc.pro = X5)


## ----echo = FALSE-----------------------------------------------------------------------------------------------------
# for square matrix filled with 0.5s
design = matrix(0.5, ncol = length(X), nrow = length(X), 
                dimnames = list(names(X), names(X)))
diag(design) = 0 # set diagonal to 0s

choice.ncomp <- 3 
choice.keepX <- list(rna = rep(50, 3), # 50 features per each component 
                     met.gene = rep(50, 3), 
                     acc.gene = rep(50, 3),
                     met.pro = rep(50, 3), 
                     acc.pro = rep(50, 3))


## ----echo = FALSE-----------------------------------------------------------------------------------------------------
final.mbspls.model = block.spls(X, indY = 1,  
                                ncomp = choice.ncomp, 
                                keepX = choice.keepX,
                                design = design)


## ----out.width = "90%", fig.align = "center", echo = FALSE------------------------------------------------------------
plotIndiv(final.mbspls.model, ind.names = FALSE,
          group = as.factor(cell_metadata$lineage), 
          pch = as.factor(cell_metadata$stage),
          col.per.group = color.mixo(1:8), 
          legend = TRUE, legend.title = 'Lineage', legend.title.pch = 'Stage',
          blocks = 1)




## ----out.width = "90%", fig.align = "center", echo = FALSE------------------------------------------------------------
plotIndiv(final.mbspls.model, ind.names = FALSE,
          group = as.factor(cell_metadata$lineage), 
          pch = as.factor(cell_metadata$stage),
          col.per.group = color.mixo(1:8), 
          legend = TRUE, legend.title = 'Lineage', legend.title.pch = 'Stage',
          blocks = 3)


## ----out.width = "90%", fig.align = "center", echo = FALSE------------------------------------------------------------
plotIndiv(final.mbspls.model, ind.names = FALSE,
          group = as.factor(cell_metadata$lineage), 
          pch = as.factor(cell_metadata$stage),
          col.per.group = color.mixo(1:8), 
          legend = TRUE, legend.title = 'Lineage', legend.title.pch = 'Stage',
          blocks = 5)

